Index: /trunk/src/VBox/Storage/DMG.cpp
===================================================================
--- /trunk/src/VBox/Storage/DMG.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/DMG.cpp	(revision 64272)
@@ -717,4 +717,6 @@
  * Swaps endian.
  * @param   pCkSum      The structure.
+ * @param   u32Kind     Kind of the checksum (CRC32, none)
+ * @param   cBits       Size of the checksum in bits.
  */
 static void dmgSwapEndianUdifCkSum(PDMGUDIFCKSUM pCkSum, uint32_t u32Kind, uint32_t cBits)
@@ -947,5 +949,5 @@
  * Finds the end tag.
  *
- * Does not deal with '<tag attr="1"/>' style tags.
+ * Does not deal with @verbatim<tag attr="1"/>@endverbatim style tags.
  *
  * @returns Pointer to the first char in the end tag. NULL if another tag
@@ -1117,5 +1119,4 @@
  * @param   pThis       The DMG instance data.
  * @param   pszXml      The XML text to parse, UTF-8.
- * @param   cch         The size of the XML text.
  */
 static const char *dmgOpenXmlToRsrc(PDMGIMAGE pThis, char const *pszXml)
@@ -1285,4 +1286,5 @@
  * @param   pThis        The DMG instance data.
  * @param   pcszRsrcName Name of the resource to get.
+ * @param   ppcRsrc      Where to store the pointer to the resource data on success.
  */
 static int dmgGetRsrcData(PDMGIMAGE pThis, const char *pcszRsrcName,
Index: /trunk/src/VBox/Storage/ISCSI.cpp
===================================================================
--- /trunk/src/VBox/Storage/ISCSI.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/ISCSI.cpp	(revision 64272)
@@ -1715,5 +1715,5 @@
  *
  * @returns VBox status code.
- * @param   pImage      The iSCSI connection state to be used.
+ * @param   pvUser      The iSCSI connection state to be used as opaque user data.
  */
 static DECLCALLBACK(int) iscsiAttach(void *pvUser)
@@ -1768,5 +1768,5 @@
  *
  * @returns VBox status code.
- * @param   pImage      The iSCSI connection state to be used.
+ * @param   pvUser      The iSCSI connection state to be used as opaque user data.
  */
 static DECLCALLBACK(int) iscsiDetach(void *pvUser)
@@ -2158,4 +2158,5 @@
  * @returns VBOX status
  * @param   pImage      The iSCSI connection state to be used.
+ * @param   itt         The initiator task tag. 
  * @param   paRes       Pointer to array of iSCSI response sections.
  * @param   cnRes       Number of valid iSCSI response sections in the array.
@@ -2967,6 +2968,6 @@
  * @param   cbBuf       Length of the key-value buffer.
  * @param   pcbBufCurr  Currently used portion of the key-value buffer.
- * @param   pszKey      Pointer to a string containing the key.
- * @param   pszValue    Pointer to either a string containing the value or to a large binary value.
+ * @param   pcszKey     Pointer to a string containing the key.
+ * @param   pcszValue   Pointer to either a string containing the value or to a large binary value.
  * @param   cbValue     Length of the binary value if applicable.
  */
@@ -3027,6 +3028,6 @@
  * @param   pbBuf       Buffer containing key=value pairs.
  * @param   cbBuf       Length of buffer with key=value pairs.
- * @param   pszKey      Pointer to key for which to retrieve the value.
- * @param   ppszValue   Pointer to value string pointer.
+ * @param   pcszKey     Pointer to key for which to retrieve the value.
+ * @param   ppcszValue  Pointer to value string pointer.
  */
 static int iscsiTextGetKeyValue(const uint8_t *pbBuf, size_t cbBuf, const char *pcszKey, const char **ppcszValue)
@@ -3054,5 +3055,5 @@
  *
  * @returns VBOX status
- * @param   pszValue    Pointer to a string containing the textual value representation.
+ * @param   pcszValue   Pointer to a string containing the textual value representation.
  * @param   pbValue     Pointer to the value buffer for the binary value.
  * @param   pcbValue    In: length of value buffer, out: actual length of binary value.
Index: /trunk/src/VBox/Storage/QCOW.cpp
===================================================================
--- /trunk/src/VBox/Storage/QCOW.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/QCOW.cpp	(revision 64272)
@@ -775,5 +775,5 @@
  * @returns The start offset of the new cluster in the image.
  * @param   pImage    The image instance data.
- * @param   cCLusters Number of clusters to allocate.
+ * @param   cClusters Number of clusters to allocate.
  */
 DECLINLINE(uint64_t) qcowClusterAllocate(PQCOWIMAGE pImage, uint32_t cClusters)
@@ -857,4 +857,6 @@
  * @param   offTbl        The offset the table should be written to.
  * @param   paTbl         The table to write.
+ * @param   cbTbl         Size of the table in bytes.
+ * @param   cTblEntries   Number entries in the table.
  * @param   pfnComplete   Callback called when the write completes.
  * @param   pvUser        Opaque user data to pass in the completion callback.
Index: /trunk/src/VBox/Storage/QED.cpp
===================================================================
--- /trunk/src/VBox/Storage/QED.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/QED.cpp	(revision 64272)
@@ -713,5 +713,5 @@
  * @returns The start offset of the new cluster in the image.
  * @param   pImage    The image instance data.
- * @param   cCLusters Number of clusters to allocate.
+ * @param   cClusters Number of clusters to allocate.
  */
 DECLINLINE(uint64_t) qedClusterAllocate(PQEDIMAGE pImage, uint32_t cClusters)
@@ -1653,5 +1653,5 @@
 }
 
-/** @copydoc VDIMAGEBACKEND::pfnWrite */
+/** @copydoc VDIMAGEBACKEND::pfnRead */
 static DECLCALLBACK(int) qedRead(void *pBackendData, uint64_t uOffset, size_t cbToRead,
                                  PVDIOCTX pIoCtx, size_t *pcbActuallyRead)
@@ -1692,5 +1692,5 @@
 }
 
-/** @copydoc VDIMAGEBACKEND::pfnRead */
+/** @copydoc VDIMAGEBACKEND::pfnWrite */
 static DECLCALLBACK(int) qedWrite(void *pBackendData, uint64_t uOffset, size_t cbToWrite,
                                   PVDIOCTX pIoCtx, size_t *pcbWriteProcess, size_t *pcbPreRead,
Index: /trunk/src/VBox/Storage/RAW.cpp
===================================================================
--- /trunk/src/VBox/Storage/RAW.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/RAW.cpp	(revision 64272)
@@ -515,5 +515,5 @@
 
 /** @copydoc VDIMAGEBACKEND::pfnRead */
-static DECLCALLBACK(int) rawRead(void *pBackendData, uint64_t uOffset, size_t cbRead,
+static DECLCALLBACK(int) rawRead(void *pBackendData, uint64_t uOffset, size_t cbToRead,
                                  PVDIOCTX pIoCtx, size_t *pcbActuallyRead)
 {
@@ -530,9 +530,9 @@
 
     rc = vdIfIoIntFileReadUser(pImage->pIfIo, pImage->pStorage, uOffset,
-                               pIoCtx, cbRead);
+                               pIoCtx, cbToRead);
     if (RT_SUCCESS(rc))
     {
-        *pcbActuallyRead = cbRead;
-        pImage->offAccess = uOffset + cbRead;
+        *pcbActuallyRead = cbToRead;
+        pImage->offAccess = uOffset + cbToRead;
     }
 
@@ -541,5 +541,5 @@
 
 /** @copydoc VDIMAGEBACKEND::pfnWrite */
-static DECLCALLBACK(int) rawWrite(void *pBackendData, uint64_t uOffset, size_t cbWrite,
+static DECLCALLBACK(int) rawWrite(void *pBackendData, uint64_t uOffset, size_t cbToWrite,
                                   PVDIOCTX pIoCtx, size_t *pcbWriteProcess, size_t *pcbPreRead,
                                   size_t *pcbPostRead, unsigned fWrite)
@@ -560,11 +560,11 @@
 
     rc = vdIfIoIntFileWriteUser(pImage->pIfIo, pImage->pStorage, uOffset,
-                                pIoCtx, cbWrite, NULL, NULL);
+                                pIoCtx, cbToWrite, NULL, NULL);
     if (RT_SUCCESS(rc))
     {
-        *pcbWriteProcess = cbWrite;
+        *pcbWriteProcess = cbToWrite;
         *pcbPostRead = 0;
         *pcbPreRead  = 0;
-        pImage->offAccess = uOffset + cbWrite;
+        pImage->offAccess = uOffset + cbToWrite;
     }
 
Index: /trunk/src/VBox/Storage/VCICache.cpp
===================================================================
--- /trunk/src/VBox/Storage/VCICache.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VCICache.cpp	(revision 64272)
@@ -447,5 +447,5 @@
  * @param   cBlocks      The number of blocks the bitmap can manage.
  * @param   ppBlkMap     Where to store the pointer to the block bitmap.
- * @param   pcbBlkMap    Where to store the size of the block bitmap in blocks
+ * @param   pcBlkMap     Where to store the size of the block bitmap in blocks
  *                       needed on the disk.
  */
@@ -1456,8 +1456,8 @@
 
 /** @copydoc VDCACHEBACKEND::pfnProbe */
-static DECLCALLBACK(int) vciProbe(const char *pszFilename, PVDINTERFACE pVDIfsCache,
+static DECLCALLBACK(int) vciProbe(const char *pszFilename, PVDINTERFACE pVDIfsDisk,
                                   PVDINTERFACE pVDIfsImage)
 {
-    RT_NOREF1(pVDIfsCache);
+    RT_NOREF1(pVDIfsDisk);
     VciHdr Hdr;
     PVDIOSTORAGE pStorage = NULL;
Index: /trunk/src/VBox/Storage/VD.cpp
===================================================================
--- /trunk/src/VBox/Storage/VD.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VD.cpp	(revision 64272)
@@ -3261,5 +3261,5 @@
  * @returns VBox status code.
  * @param   pDisk              VD disk container.
- * @param   pDiscard           The discard state.
+ * @param   pIoCtx             The I/O context associated with this discard operation.
  * @param   cbDiscardingNew    How many bytes should be waiting on success.
  *                             The number of bytes waiting can be less.
@@ -4502,4 +4502,5 @@
  * @returns VBox status code.
  * @param   pDisk    The disk to unlock.
+ * @param   pIoCtxRc The I/O context to get the status code from, optional.
  */
 static int vdDiskUnlock(PVBOXHDD pDisk, PVDIOCTX pIoCtxRc)
@@ -5974,5 +5975,5 @@
  * @returns VBox status code.
  * @param   pszBackend      The backend name.
- * @param   pEntries        Pointer to an entry.
+ * @param   pEntry          Pointer to an entry.
  */
 VBOXDDU_DECL(int) VDBackendInfoOne(const char *pszBackend, PVDBACKENDINFO pEntry)
@@ -6055,5 +6056,5 @@
  * @return  VBox status code.
  * @param   pszFilter       The filter name (case insensitive).
- * @param   pEntries        Pointer to an entry.
+ * @param   pEntry          Pointer to an entry.
  */
 VBOXDDU_DECL(int) VDFilterInfoOne(const char *pszFilter, PVDFILTERINFO pEntry)
@@ -8178,6 +8179,6 @@
  * read/write behavior in this situation this needs to be extended.
  *
- * @return  VBox status code.
- * @return  VERR_VD_IMAGE_NOT_FOUND if image with specified number was not opened.
+ * @returns VBox status code.
+ * @retval  VERR_VD_IMAGE_NOT_FOUND if image with specified number was not opened.
  * @param   pDiskFrom       Pointer to source HDD container.
  * @param   nImage          Image number, counts from 0. 0 is always base image of container.
@@ -8189,6 +8190,6 @@
  * @param   fMoveByRename   If true, attempt to perform a move by renaming (if successful the new size is ignored).
  * @param   cbSize          New image size (0 means leave unchanged).
- * @param   nImageSameFrom  todo
- * @param   nImageSameTo    todo
+ * @param   nImageFromSame  todo
+ * @param   nImageToSame    todo
  * @param   uImageFlags     Flags specifying special destination image features.
  * @param   pDstUuid        New UUID of the destination image. If NULL, a new UUID is created.
@@ -9313,5 +9314,5 @@
  *
  * @returns VBox status code.
- * @returns VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  * @param   uOffset         Offset of first reading byte from start of disk.
@@ -9381,5 +9382,5 @@
  *
  * @returns VBox status code.
- * @returns VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  * @param   uOffset         Offset of the first byte being
@@ -9456,5 +9457,5 @@
  *
  * @returns VBox status code.
- * @returns VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  */
@@ -10094,8 +10095,8 @@
  *
  * @returns VBox status code.
- * @returns VERR_VD_IMAGE_NOT_FOUND if image with specified number was not opened.
+ * @retval  VERR_VD_IMAGE_NOT_FOUND if image with specified number was not opened.
  * @param   pDisk           Pointer to the HDD container.
  * @param   nImage          Image number, counts from 0. 0 is always base image of container.
- * @param   pbackendInfo    Where to store the backend information.
+ * @param   pBackendInfo    Where to store the backend information.
  */
 VBOXDDU_DECL(int) VDBackendInfoSingle(PVBOXHDD pDisk, unsigned nImage,
Index: /trunk/src/VBox/Storage/VDI.cpp
===================================================================
--- /trunk/src/VBox/Storage/VDI.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VDI.cpp	(revision 64272)
@@ -327,5 +327,13 @@
 /**
  * Internal: Init VDI header. Always use latest header version.
- * @param   pHeader     Assumes it was initially initialized to all zeros.
+ *
+ * @returns nothing.
+ * @param   pHeader      Assumes it was initially initialized to all zeros.
+ * @param   uImageFlags  Flags for this image.
+ * @param   pszComment   Optional comment to set for the image.
+ * @param   cbDisk       Size of the disk in bytes.
+ * @param   cbBlock      Size of one block in the image.
+ * @param   cbBlockExtra Extra data for one block private to the image.
+ * @param   cbDataAlign  The alignment for all data structures.
  */
 static void vdiInitHeader(PVDIHEADER pHeader, uint32_t uImageFlags,
@@ -1935,5 +1943,5 @@
 }
 
-/** @copydoc VDIMAGEBACKEND::pfnGetComment */
+/** @copydoc VDIMAGEBACKEND::pfnSetComment */
 static DECLCALLBACK(int) vdiSetComment(void *pBackendData, const char *pszComment)
 {
Index: /trunk/src/VBox/Storage/VDIfVfs2.cpp
===================================================================
--- /trunk/src/VBox/Storage/VDIfVfs2.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VDIfVfs2.cpp	(revision 64272)
@@ -167,5 +167,5 @@
 /** @interface_method_impl{VDINTERFACEIO,pfnOpen}  */
 static DECLCALLBACK(int) vdIfFromVfs_Open(void *pvUser, const char *pszLocation, uint32_t fOpen,
-                                          PFNVDCOMPLETED pfnCompleted, void **ppInt)
+                                          PFNVDCOMPLETED pfnCompleted, void **ppvStorage)
 {
     RT_NOREF1(pszLocation);
@@ -175,5 +175,5 @@
      * Validate input.
      */
-    AssertPtrReturn(ppInt, VERR_INVALID_POINTER);
+    AssertPtrReturn(ppvStorage, VERR_INVALID_POINTER);
     AssertPtrNullReturn(pfnCompleted, VERR_INVALID_PARAMETER);
 
@@ -192,5 +192,5 @@
     pThis->pvCompletedUser  = pvUser;
 
-    *ppInt = pThis->hVfsIos;
+    *ppvStorage = pThis->hVfsIos;
     return VINF_SUCCESS;
 }
Index: /trunk/src/VBox/Storage/VHD.cpp
===================================================================
--- /trunk/src/VBox/Storage/VHD.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VHD.cpp	(revision 64272)
@@ -1448,5 +1448,5 @@
 
 /** @interface_method_impl{VDIMAGEBACKEND,pfnRead} */
-static DECLCALLBACK(int) vhdRead(void *pBackendData, uint64_t uOffset, size_t cbRead,
+static DECLCALLBACK(int) vhdRead(void *pBackendData, uint64_t uOffset, size_t cbToRead,
                                  PVDIOCTX pIoCtx, size_t *pcbActuallyRead)
 {
@@ -1454,11 +1454,12 @@
     int rc = VINF_SUCCESS;
 
-    LogFlowFunc(("pBackendData=%p uOffset=%#llx pIoCtx=%#p cbRead=%u pcbActuallyRead=%p\n", pBackendData, uOffset, pIoCtx, cbRead, pcbActuallyRead));
+    LogFlowFunc(("pBackendData=%p uOffset=%#llx pIoCtx=%#p cbToRead=%u pcbActuallyRead=%p\n",
+                 pBackendData, uOffset, pIoCtx, cbToRead, pcbActuallyRead));
 
     AssertPtr(pImage);
     Assert(uOffset % 512 == 0);
-    Assert(cbRead % 512 == 0);
-    AssertReturn((VALID_PTR(pIoCtx) && cbRead), VERR_INVALID_PARAMETER);
-    AssertReturn(uOffset + cbRead <= pImage->cbSize, VERR_INVALID_PARAMETER);
+    Assert(cbToRead % 512 == 0);
+    AssertReturn((VALID_PTR(pIoCtx) && cbToRead), VERR_INVALID_PARAMETER);
+    AssertReturn(uOffset + cbToRead <= pImage->cbSize, VERR_INVALID_PARAMETER);
 
     /*
@@ -1480,5 +1481,5 @@
          * Clip read range to remain in this data block.
          */
-        cbRead = RT_MIN(cbRead, (pImage->cbDataBlock - (cBATEntryIndex * VHD_SECTOR_SIZE)));
+        cbToRead = RT_MIN(cbToRead, (pImage->cbDataBlock - (cBATEntryIndex * VHD_SECTOR_SIZE)));
 
         /*
@@ -1490,5 +1491,5 @@
         {
             uVhdOffset = ((uint64_t)pImage->pBlockAllocationTable[cBlockAllocationTableEntry] + pImage->cDataBlockBitmapSectors + cBATEntryIndex) * VHD_SECTOR_SIZE;
-            LogFlowFunc(("uVhdOffset=%llu cbRead=%u\n", uVhdOffset, cbRead));
+            LogFlowFunc(("uVhdOffset=%llu cbToRead=%u\n", uVhdOffset, cbToRead));
 
             /* Read in the block's bitmap. */
@@ -1514,5 +1515,5 @@
                      * must be read from child.
                      */
-                    while (   (cSectors < (cbRead / VHD_SECTOR_SIZE))
+                    while (   (cSectors < (cbToRead / VHD_SECTOR_SIZE))
                            && vhdBlockBitmapSectorContainsData(pImage, cBATEntryIndex))
                     {
@@ -1521,9 +1522,9 @@
                     }
 
-                    cbRead = cSectors * VHD_SECTOR_SIZE;
-
-                    LogFlowFunc(("uVhdOffset=%llu cbRead=%u\n", uVhdOffset, cbRead));
+                    cbToRead = cSectors * VHD_SECTOR_SIZE;
+
+                    LogFlowFunc(("uVhdOffset=%llu cbToRead=%u\n", uVhdOffset, cbToRead));
                     rc = vdIfIoIntFileReadUser(pImage->pIfIo, pImage->pStorage,
-                                               uVhdOffset, pIoCtx, cbRead);
+                                               uVhdOffset, pIoCtx, cbToRead);
                 }
                 else
@@ -1540,5 +1541,5 @@
                     cSectors = 1;
 
-                    while (   (cSectors < (cbRead / VHD_SECTOR_SIZE))
+                    while (   (cSectors < (cbToRead / VHD_SECTOR_SIZE))
                            && !vhdBlockBitmapSectorContainsData(pImage, cBATEntryIndex))
                     {
@@ -1547,6 +1548,6 @@
                     }
 
-                    cbRead = cSectors * VHD_SECTOR_SIZE;
-                    LogFunc(("Sectors free: uVhdOffset=%llu cbRead=%u\n", uVhdOffset, cbRead));
+                    cbToRead = cSectors * VHD_SECTOR_SIZE;
+                    LogFunc(("Sectors free: uVhdOffset=%llu cbToRead=%u\n", uVhdOffset, cbToRead));
                     rc = VERR_VD_BLOCK_FREE;
                 }
@@ -1557,8 +1558,8 @@
     }
     else
-        rc = vdIfIoIntFileReadUser(pImage->pIfIo, pImage->pStorage, uOffset, pIoCtx, cbRead);
+        rc = vdIfIoIntFileReadUser(pImage->pIfIo, pImage->pStorage, uOffset, pIoCtx, cbToRead);
 
     if (pcbActuallyRead)
-        *pcbActuallyRead = cbRead;
+        *pcbActuallyRead = cbToRead;
 
     LogFlowFunc(("returns rc=%Rrc\n", rc));
@@ -1567,5 +1568,5 @@
 
 /** @interface_method_impl{VDIMAGEBACKEND,pfnWrite} */
-static DECLCALLBACK(int) vhdWrite(void *pBackendData, uint64_t uOffset, size_t cbWrite,
+static DECLCALLBACK(int) vhdWrite(void *pBackendData, uint64_t uOffset, size_t cbToWrite,
                          PVDIOCTX pIoCtx, size_t *pcbWriteProcess, size_t *pcbPreRead,
                          size_t *pcbPostRead, unsigned fWrite)
@@ -1574,12 +1575,12 @@
     int rc = VINF_SUCCESS;
 
-    LogFlowFunc(("pBackendData=%p uOffset=%llu pIoCtx=%#p cbWrite=%u pcbWriteProcess=%p pcbPreRead=%p pcbPostRead=%p fWrite=%u\n",
-             pBackendData, uOffset, pIoCtx, cbWrite, pcbWriteProcess, pcbPreRead, pcbPostRead, fWrite));
+    LogFlowFunc(("pBackendData=%p uOffset=%llu pIoCtx=%#p cbToWrite=%u pcbWriteProcess=%p pcbPreRead=%p pcbPostRead=%p fWrite=%u\n",
+             pBackendData, uOffset, pIoCtx, cbToWrite, pcbWriteProcess, pcbPreRead, pcbPostRead, fWrite));
 
     AssertPtr(pImage);
     Assert(!(uOffset % VHD_SECTOR_SIZE));
-    Assert(!(cbWrite % VHD_SECTOR_SIZE));
-    AssertReturn((VALID_PTR(pIoCtx) && cbWrite), VERR_INVALID_PARAMETER);
-    AssertReturn(uOffset + cbWrite <= pImage->cbSize, VERR_INVALID_PARAMETER);
+    Assert(!(cbToWrite % VHD_SECTOR_SIZE));
+    AssertReturn((VALID_PTR(pIoCtx) && cbToWrite), VERR_INVALID_PARAMETER);
+    AssertReturn(uOffset + cbToWrite <= pImage->cbSize, VERR_INVALID_PARAMETER);
 
     if (pImage->pBlockAllocationTable)
@@ -1596,5 +1597,5 @@
          * Clip write range.
          */
-        cbWrite = RT_MIN(cbWrite, (pImage->cbDataBlock - (cBATEntryIndex * VHD_SECTOR_SIZE)));
+        cbToWrite = RT_MIN(cbToWrite, (pImage->cbDataBlock - (cBATEntryIndex * VHD_SECTOR_SIZE)));
 
         /*
@@ -1611,11 +1612,11 @@
             /* Check if the block allocation should be suppressed. */
             if (   (fWrite & VD_WRITE_NO_ALLOC)
-                || (cbWrite != pImage->cbDataBlock))
+                || (cbToWrite != pImage->cbDataBlock))
             {
                 *pcbPreRead = cBATEntryIndex * VHD_SECTOR_SIZE;
-                *pcbPostRead = pImage->cSectorsPerDataBlock * VHD_SECTOR_SIZE - cbWrite - *pcbPreRead;
+                *pcbPostRead = pImage->cSectorsPerDataBlock * VHD_SECTOR_SIZE - cbToWrite - *pcbPreRead;
 
                 if (pcbWriteProcess)
-                    *pcbWriteProcess = cbWrite;
+                    *pcbWriteProcess = cbToWrite;
                 return VERR_VD_BLOCK_FREE;
             }
@@ -1632,5 +1633,5 @@
 
             /* Set the bits for all sectors having been written. */
-            for (uint32_t iSector = 0; iSector < (cbWrite / VHD_SECTOR_SIZE); iSector++)
+            for (uint32_t iSector = 0; iSector < (cbToWrite / VHD_SECTOR_SIZE); iSector++)
             {
                 /* No need to check for a changed value because this is an initial write. */
@@ -1669,5 +1670,5 @@
                 rc = vdIfIoIntFileWriteUser(pImage->pIfIo, pImage->pStorage,
                                             pImage->uCurrentEndOfFile + (pImage->cDataBlockBitmapSectors + (cSector % pImage->cSectorsPerDataBlock)) * VHD_SECTOR_SIZE,
-                                            pIoCtx, cbWrite,
+                                            pIoCtx, cbToWrite,
                                             vhdAsyncExpansionDataComplete,
                                             pExpand);
@@ -1752,5 +1753,5 @@
                 /* Write data. */
                 rc = vdIfIoIntFileWriteUser(pImage->pIfIo, pImage->pStorage,
-                                            uVhdOffset, pIoCtx, cbWrite,
+                                            uVhdOffset, pIoCtx, cbToWrite,
                                             NULL, NULL);
                 if (RT_SUCCESS(rc) || rc == VERR_VD_ASYNC_IO_IN_PROGRESS)
@@ -1759,5 +1760,5 @@
 
                     /* Set the bits for all sectors having been written. */
-                    for (uint32_t iSector = 0; iSector < (cbWrite / VHD_SECTOR_SIZE); iSector++)
+                    for (uint32_t iSector = 0; iSector < (cbToWrite / VHD_SECTOR_SIZE); iSector++)
                     {
                         fChanged |= vhdBlockBitmapSectorSet(pImage, pImage->pu8Bitmap, cBATEntryIndex);
@@ -1789,8 +1790,8 @@
     else
         rc = vdIfIoIntFileWriteUser(pImage->pIfIo, pImage->pStorage,
-                                    uOffset, pIoCtx, cbWrite, NULL, NULL);
+                                    uOffset, pIoCtx, cbToWrite, NULL, NULL);
 
     if (pcbWriteProcess)
-        *pcbWriteProcess = cbWrite;
+        *pcbWriteProcess = cbToWrite;
 
     /* Stay on the safe side. Do not run the risk of confusing the higher
Index: /trunk/src/VBox/Storage/VHDX.cpp
===================================================================
--- /trunk/src/VBox/Storage/VHDX.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VHDX.cpp	(revision 64272)
@@ -79,5 +79,5 @@
     /** Version of the log format. */
     uint16_t    u16LogVersion;
-    /** VHDX format version.. */
+    /** VHDX format version. */
     uint16_t    u16Version;
     /** Length of the log region. */
@@ -803,4 +803,5 @@
  * @param   paBatEntriesConv    Where to store the converted BAT.
  * @param   paBatEntries        The VHDX BAT to convert.
+ * @param   cBatEntries         Number of entries in the BAT.
  *
  * @note It is safe to use the same pointer for paBatEntriesConv and paBatEntries.
Index: /trunk/src/VBox/Storage/VMDK.cpp
===================================================================
--- /trunk/src/VBox/Storage/VMDK.cpp	(revision 64271)
+++ /trunk/src/VBox/Storage/VMDK.cpp	(revision 64272)
@@ -1379,6 +1379,13 @@
 
 /**
+ * Unquotes the given string returning the result in a separate buffer.
+ *
+ * @returns VBox status code.
+ * @param   pImage          The VMDK image state.
+ * @param   pszStr          The string to unquote.
  * @param   ppszUnquoted    Where to store the return value, use RTMemTmpFree to
  *                          free.
+ * @param   ppszNext        Where to store the pointer to any character following
+ *                          the quoted value, optional.
  */
 static int vmdkStringUnquote(PVMDKIMAGE pImage, const char *pszStr,
@@ -1590,4 +1597,11 @@
 
 /**
+ * Returns the value of the given key as a string allocating the necessary memory.
+ *
+ * @returns VBox status code.
+ * @retval  VERR_VD_VMDK_VALUE_NOT_FOUND if the value could not be found.
+ * @param   pImage          The VMDK image state.
+ * @param   pDescriptor     The descriptor to fetch the value from.
+ * @param   pszKey          The key to get the value from.
  * @param   ppszValue       Where to store the return value, use RTMemTmpFree to
  *                          free.
@@ -1728,4 +1742,12 @@
 
 /**
+ * Returns the value of the given key from the DDB as a string allocating
+ * the necessary memory.
+ *
+ * @returns VBox status code.
+ * @retval  VERR_VD_VMDK_VALUE_NOT_FOUND if the value could not be found.
+ * @param   pImage          The VMDK image state.
+ * @param   pDescriptor     The descriptor to fetch the value from.
+ * @param   pszKey          The key to get the value from.
  * @param   ppszValue       Where to store the return value, use RTMemTmpFree to
  *                          free.

Index: /trunk/include/VBox/vd-cache-backend.h
===================================================================
--- /trunk/include/VBox/vd-cache-backend.h	(revision 64271)
+++ /trunk/include/VBox/vd-cache-backend.h	(revision 64272)
@@ -125,9 +125,9 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to read from.
      * @param   cbRead          How many bytes to read.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbActuallyRead Pointer to returned number of bytes read.
      */
-    DECLR3CALLBACKMEMBER(int, pfnRead, (void *pBackendData, uint64_t uOffset, size_t cbRead,
+    DECLR3CALLBACKMEMBER(int, pfnRead, (void *pBackendData, uint64_t uOffset, size_t cbToRead,
                                         PVDIOCTX pIoCtx, size_t *pcbActuallyRead));
 
@@ -138,5 +138,5 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to write to.
      * @param   cbWrite         How many bytes to write.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbWriteProcess Pointer to returned number of bytes that could
@@ -147,5 +147,5 @@
      *                          amount of (previously read) padding data.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWrite, (void *pBackendData, uint64_t uOffset, size_t cbWrite,
+    DECLR3CALLBACKMEMBER(int, pfnWrite, (void *pBackendData, uint64_t uOffset, size_t cbToWrite,
                                          PVDIOCTX pIoCtx, size_t *pcbWriteProcess));
 
@@ -125,9 +125,9 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to read from.
-     * @param   cbRead          How many bytes to read.
+     * @param   cbToRead        How many bytes to read.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbActuallyRead Pointer to returned number of bytes read.
@@ -138,5 +138,5 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to write to.
-     * @param   cbWrite         How many bytes to write.
+     * @param   cbToWrite       How many bytes to write.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbWriteProcess Pointer to returned number of bytes that could
Index: /trunk/include/VBox/vd-ifs.h
===================================================================
--- /trunk/include/VBox/vd-ifs.h	(revision 64271)
+++ /trunk/include/VBox/vd-ifs.h	(revision 64272)
@@ -357,10 +357,10 @@
      *                          VDAsyncRead or VDAsyncWrite) in pvCompletion
      *                          if this is NULL.
      * @param   ppStorage       Where to store the opaque storage handle.
      */
     DECLR3CALLBACKMEMBER(int, pfnOpen, (void *pvUser, const char *pszLocation,
                                         uint32_t fOpen,
                                         PFNVDCOMPLETED pfnCompleted,
-                                        void **ppStorage));
+                                        void **ppvStorage));
 
     /**
@@ -369,7 +369,7 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The opaque storage handle to close.
-     */
-    DECLR3CALLBACKMEMBER(int, pfnClose, (void *pvUser, void *pStorage));
+     * @param   pvStorage       The opaque storage handle to close.
+     */
+    DECLR3CALLBACKMEMBER(int, pfnClose, (void *pvUser, void *pvStorage));
 
     /**
@@ -419,8 +419,8 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The opaque storage handle to close.
-     * @param   pcbSize         Where to store the size of the storage backend.
-     */
-    DECLR3CALLBACKMEMBER(int, pfnGetSize, (void *pvUser, void *pStorage, uint64_t *pcbSize));
+     * @param   pvStorage       The opaque storage handle to get the size from.
+     * @param   pcb             Where to store the size of the storage backend.
+     */
+    DECLR3CALLBACKMEMBER(int, pfnGetSize, (void *pvUser, void *pvStorage, uint64_t *pcb));
 
     /**
@@ -430,6 +430,6 @@
      * @retval  VERR_NOT_SUPPORTED if the backend does not support this operation.
      * @param   pvUser          The opaque data passed on container creation.
      * @param   pStorage        The opaque storage handle to close.
      * @param   cbSize          The new size of the image.
      *
      * @note Depending on the host the underlying storage (backing file, etc.)
@@ -441,5 +441,5 @@
      *       really alloacted.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSetSize, (void *pvUser, void *pStorage, uint64_t cbSize));
+    DECLR3CALLBACKMEMBER(int, pfnSetSize, (void *pvUser, void *pvStorage, uint64_t cb));
 
     /**
@@ -451,10 +451,10 @@
      *         this method.
      * @param  pvUser          The opaque data passed on container creation.
      * @param  pStorage        The storage handle.
      * @param  cbSize          The new size of the image.
      * @param  fFlags          Flags for controlling the allocation strategy.
      *                         Reserved for future use, MBZ.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSetAllocationSize, (void *pvUser, void *pStorage,
+    DECLR3CALLBACKMEMBER(int, pfnSetAllocationSize, (void *pvUser, void *pvStorage,
                                                      uint64_t cbSize, uint32_t fFlags));
 
@@ -464,12 +464,12 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
      * @param   pStorage        The storage handle to use.
      * @param   uOffset         The offset to start from.
      * @param   pvBuffer        Pointer to the bits need to be written.
      * @param   cbBuffer        How many bytes to write.
      * @param   pcbWritten      Where to store how many bytes were actually written.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWriteSync, (void *pvUser, void *pStorage, uint64_t uOffset,
-                                             const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten));
+    DECLR3CALLBACKMEMBER(int, pfnWriteSync, (void *pvUser, void *pvStorage, uint64_t off,
+                                             const void *pvBuf, size_t cbToWrite, size_t *pcbWritten));
 
     /**
@@ -478,12 +478,12 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
      * @param   pStorage        The storage handle to use.
      * @param   uOffset         The offset to start from.
      * @param   pvBuffer        Where to store the read bits.
      * @param   cbBuffer        How many bytes to read.
      * @param   pcbRead         Where to store how many bytes were actually read.
      */
-    DECLR3CALLBACKMEMBER(int, pfnReadSync, (void *pvUser, void *pStorage, uint64_t uOffset,
-                                            void *pvBuffer, size_t cbBuffer, size_t *pcbRead));
+    DECLR3CALLBACKMEMBER(int, pfnReadSync, (void *pvUser, void *pvStorage, uint64_t off,
+                                            void *pvBuf, size_t cbToRead, size_t *pcbRead));
 
     /**
@@ -492,7 +492,7 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The storage handle to flush.
-     */
-    DECLR3CALLBACKMEMBER(int, pfnFlushSync, (void *pvUser, void *pStorage));
+     * @param   pvStorage       The storage handle to flush.
+     */
+    DECLR3CALLBACKMEMBER(int, pfnFlushSync, (void *pvUser, void *pvStorage));
 
     /**
@@ -501,5 +501,5 @@
      * @return  VBox status code.
      * @param   pvUser         The opaque user data passed on container creation.
      * @param   pStorage       The storage handle.
      * @param   uOffset        The offset to start reading from.
      * @param   paSegments     Scatter gather list to store the data in.
@@ -509,5 +509,5 @@
      * @param   ppTask         Where to store the opaque task handle.
      */
-    DECLR3CALLBACKMEMBER(int, pfnReadAsync, (void *pvUser, void *pStorage, uint64_t uOffset,
+    DECLR3CALLBACKMEMBER(int, pfnReadAsync, (void *pvUser, void *pvStorage, uint64_t uOffset,
                                              PCRTSGSEG paSegments, size_t cSegments,
                                              size_t cbRead, void *pvCompletion,
@@ -519,5 +519,5 @@
      * @return  VBox status code.
      * @param   pvUser         The opaque user data passed on conatiner creation.
      * @param   pStorage       The storage handle.
      * @param   uOffset        The offset to start writing to.
      * @param   paSegments     Scatter gather list of the data to write
@@ -527,5 +527,5 @@
      * @param   ppTask         Where to store the opaque task handle.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWriteAsync, (void *pvUser, void *pStorage, uint64_t uOffset,
+    DECLR3CALLBACKMEMBER(int, pfnWriteAsync, (void *pvUser, void *pvStorage, uint64_t uOffset,
                                               PCRTSGSEG paSegments, size_t cSegments,
                                               size_t cbWrite, void *pvCompletion,
@@ -537,9 +537,9 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
      * @param   pStorage        The storage handle to flush.
      * @param   pvCompletion    The opaque user data which is returned upon completion.
      * @param   ppTask          Where to store the opaque task handle.
      */
-    DECLR3CALLBACKMEMBER(int, pfnFlushAsync, (void *pvUser, void *pStorage,
+    DECLR3CALLBACKMEMBER(int, pfnFlushAsync, (void *pvUser, void *pvStorage,
                                               void *pvCompletion, void **ppTask));
 
@@ -357,10 +357,10 @@
      *                          VDAsyncRead or VDAsyncWrite) in pvCompletion
      *                          if this is NULL.
-     * @param   ppStorage       Where to store the opaque storage handle.
+     * @param   ppvStorage      Where to store the opaque storage handle.
      */
     DECLR3CALLBACKMEMBER(int, pfnOpen, (void *pvUser, const char *pszLocation,
@@ -430,6 +430,6 @@
      * @retval  VERR_NOT_SUPPORTED if the backend does not support this operation.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The opaque storage handle to close.
-     * @param   cbSize          The new size of the image.
+     * @param   pvStorage       The opaque storage handle to set the size for.
+     * @param   cb              The new size of the image.
      *
      * @note Depending on the host the underlying storage (backing file, etc.)
@@ -451,10 +451,10 @@
      *         this method.
      * @param  pvUser          The opaque data passed on container creation.
-     * @param  pStorage        The storage handle.
+     * @param  pvStorage       The storage handle.
      * @param  cbSize          The new size of the image.
      * @param  fFlags          Flags for controlling the allocation strategy.
@@ -464,12 +464,12 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The storage handle to use.
-     * @param   uOffset         The offset to start from.
-     * @param   pvBuffer        Pointer to the bits need to be written.
-     * @param   cbBuffer        How many bytes to write.
+     * @param   pvStorage       The storage handle to use.
+     * @param   off             The offset to start from.
+     * @param   pvBuf           Pointer to the bits need to be written.
+     * @param   cbToWrite       How many bytes to write.
      * @param   pcbWritten      Where to store how many bytes were actually written.
      */
@@ -478,12 +478,12 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The storage handle to use.
-     * @param   uOffset         The offset to start from.
-     * @param   pvBuffer        Where to store the read bits.
-     * @param   cbBuffer        How many bytes to read.
+     * @param   pvStorage       The storage handle to use.
+     * @param   off             The offset to start from.
+     * @param   pvBuf           Where to store the read bits.
+     * @param   cbToRead        How many bytes to read.
      * @param   pcbRead         Where to store how many bytes were actually read.
      */
@@ -501,5 +501,5 @@
      * @return  VBox status code.
      * @param   pvUser         The opaque user data passed on container creation.
-     * @param   pStorage       The storage handle.
+     * @param   pvStorage      The storage handle.
      * @param   uOffset        The offset to start reading from.
      * @param   paSegments     Scatter gather list to store the data in.
@@ -519,5 +519,5 @@
      * @return  VBox status code.
      * @param   pvUser         The opaque user data passed on conatiner creation.
-     * @param   pStorage       The storage handle.
+     * @param   pvStorage      The storage handle.
      * @param   uOffset        The offset to start writing to.
      * @param   paSegments     Scatter gather list of the data to write
@@ -537,9 +537,9 @@
      * @return  VBox status code.
      * @param   pvUser          The opaque data passed on container creation.
-     * @param   pStorage        The storage handle to flush.
+     * @param   pvStorage       The storage handle to flush.
      * @param   pvCompletion    The opaque user data which is returned upon completion.
      * @param   ppTask          Where to store the opaque task handle.
Index: /trunk/include/VBox/vd-image-backend.h
===================================================================
--- /trunk/include/VBox/vd-image-backend.h	(revision 64271)
+++ /trunk/include/VBox/vd-image-backend.h	(revision 64272)
@@ -177,9 +177,9 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to read from.
      * @param   cbRead          How many bytes to read.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbActuallyRead Pointer to returned number of bytes read.
      */
-    DECLR3CALLBACKMEMBER(int, pfnRead, (void *pBackendData, uint64_t uOffset, size_t cbRead,
+    DECLR3CALLBACKMEMBER(int, pfnRead, (void *pBackendData, uint64_t uOffset, size_t cbToRead,
                                         PVDIOCTX pIoCtx, size_t *pcbActuallyRead));
 
@@ -190,5 +190,5 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to write to.
      * @param   cbWrite         How many bytes to write.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbWriteProcess Pointer to returned number of bytes that could
@@ -205,5 +205,5 @@
      *                          of the VD_WRITE_* flags.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWrite, (void *pBackendData, uint64_t uOffset, size_t cbWrite,
+    DECLR3CALLBACKMEMBER(int, pfnWrite, (void *pBackendData, uint64_t uOffset, size_t cbToWrite,
                                          PVDIOCTX pIoCtx,
                                          size_t *pcbWriteProcess, size_t *pcbPreRead,
@@ -480,6 +480,6 @@
      *
      * @returns VBox status code.
-     * @param   pBackendData      Opaque state data for this image.
-     * @param   pszParentFilename Where to store the path.
+     * @param   pBackendData       Opaque state data for this image.
+     * @param   ppszParentFilename Where to store the path.
      */
     DECLR3CALLBACKMEMBER(int, pfnGetParentFilename, (void *pBackendData, char **ppszParentFilename));
@@ -177,9 +177,9 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to read from.
-     * @param   cbRead          How many bytes to read.
+     * @param   cbToRead        How many bytes to read.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbActuallyRead Pointer to returned number of bytes read.
@@ -190,5 +190,5 @@
      * @param   pBackendData    Opaque state data for this image.
      * @param   uOffset         The offset of the virtual disk to write to.
-     * @param   cbWrite         How many bytes to write.
+     * @param   cbToWrite       How many bytes to write.
      * @param   pIoCtx          I/O context associated with this request.
      * @param   pcbWriteProcess Pointer to returned number of bytes that could
Index: /trunk/include/VBox/vd.h
===================================================================
--- /trunk/include/VBox/vd.h	(revision 64271)
+++ /trunk/include/VBox/vd.h	(revision 64272)
@@ -1002,13 +1002,13 @@
  *
  * @return  VBox status code.
  * @return  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  * @param   off             Offset of first reading byte from start of disk.
  *                          Must be aligned to a sector boundary.
  * @param   pvBuffer        Pointer to buffer for reading data.
  * @param   cbBuffer        Number of bytes to read.
  *                          Must be aligned to a sector boundary.
  */
-VBOXDDU_DECL(int) VDRead(PVBOXHDD pDisk, uint64_t off, void *pvBuffer, size_t cbBuffer);
+VBOXDDU_DECL(int) VDRead(PVBOXHDD pDisk, uint64_t uOffset, void *pvBuf, size_t cbRead);
 
 /**
@@ -1016,13 +1016,13 @@
  *
  * @return  VBox status code.
  * @return  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  * @param   off             Offset of first writing byte from start of disk.
  *                          Must be aligned to a sector boundary.
  * @param   pvBuffer        Pointer to buffer for writing data.
  * @param   cbBuffer        Number of bytes to write.
  *                          Must be aligned to a sector boundary.
  */
-VBOXDDU_DECL(int) VDWrite(PVBOXHDD pDisk, uint64_t off, const void *pvBuffer, size_t cbBuffer);
+VBOXDDU_DECL(int) VDWrite(PVBOXHDD pDisk, uint64_t uOffset, const void *pvBuf, size_t cbWrite);
 
 /**
@@ -1030,5 +1030,5 @@
  *
  * @return  VBox status code.
- * @return  VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
  * @param   pDisk           Pointer to HDD container.
  */
@@ -1002,13 +1002,13 @@
  *
  * @return  VBox status code.
- * @return  VERR_VD_NOT_OPENED if no image is opened in HDD container.
- * @param   pDisk           Pointer to HDD container.
- * @param   off             Offset of first reading byte from start of disk.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @param   pDisk           Pointer to HDD container.
+ * @param   uOffset         Offset of first reading byte from start of disk.
  *                          Must be aligned to a sector boundary.
@@ -1002,13 +1002,13 @@
  *                          Must be aligned to a sector boundary.
- * @param   pvBuffer        Pointer to buffer for reading data.
- * @param   cbBuffer        Number of bytes to read.
+ * @param   pvBuf           Pointer to buffer for reading data.
+ * @param   cbRead          Number of bytes to read.
  *                          Must be aligned to a sector boundary.
  */
@@ -1016,13 +1016,13 @@
  *
  * @return  VBox status code.
- * @return  VERR_VD_NOT_OPENED if no image is opened in HDD container.
- * @param   pDisk           Pointer to HDD container.
- * @param   off             Offset of first writing byte from start of disk.
+ * @retval  VERR_VD_NOT_OPENED if no image is opened in HDD container.
+ * @param   pDisk           Pointer to HDD container.
+ * @param   uOffset         Offset of first writing byte from start of disk.
  *                          Must be aligned to a sector boundary.
@@ -1016,13 +1016,13 @@
  *                          Must be aligned to a sector boundary.
- * @param   pvBuffer        Pointer to buffer for writing data.
- * @param   cbBuffer        Number of bytes to write.
+ * @param   pvBuf           Pointer to buffer for writing data.
+ * @param   cbWrite         Number of bytes to write.
  *                          Must be aligned to a sector boundary.
  */